@@ -1,12 +1,12 @@
 package MooseX::Declare::Context::Namespaced;
 # ABSTRACT: Namespaced context
-$MooseX::Declare::Context::Namespaced::VERSION = '0.40';
-use Moose::Role;
 
+our $VERSION = '0.41';
+
+use Moose::Role;
 use Carp                  qw( croak );
 use MooseX::Declare::Util qw( outer_stack_peek );
-
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 #pod =head1 DESCRIPTION
 #pod
@@ -93,7 +93,7 @@ MooseX::Declare::Context::Namespaced - Namespaced context
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 DESCRIPTION
 
